require(methods)

setClass("altered",representation(exprs="data.frame",fscore="numeric",rrv="numeric",
         len="numeric", iter="numeric", vsize="numeric",pctsubset="numeric",filmed="numeric"))

setMethod("show","altered",
	function(object) print(rownames(object@exprs))
)

setGeneric("getExprs",function(object) standardGeneric("getExprs"))

setMethod("getExprs","altered",
	function(object) object@exprs
)

setGeneric("getGenes",function(object) standardGeneric("getGenes"))

setMethod("getGenes","altered",
	function(object) rownames(object@exprs)
)

setGeneric("plotExprs",function(altered) standardGeneric("plotExprs"))

setMethod("plotExprs","altered",
	function(altered){
	exprmat <- as.matrix(altered@exprs)
	plot(c(1,dim(exprmat)[2]+1),c(min(exprmat),max(exprmat)),type="n",xlab="Samples",ylab="Expression value")
	abline(h=0,v=(altered@len),col=2)
	for(j in c(1:dim(exprmat)[1])){
		points(exprmat[j,],type = "l",col = j)
	}
	}
)

setGeneric("plotScal",function(altered) standardGeneric("plotScal"))

setMethod("plotScal","altered",
	function(altered)
	{
	# Generación del gráfico escalado
	exprmat <- as.matrix(altered@exprs)
	plot(c(1,dim(exprmat)[2]+1),c(min(exprmat/exprmat[,1]),max(exprmat/exprmat[,1])),type="n",xlab="Samples",ylab="Expression value (Scaled)")
	#plot(c(1,dim(exprmat)[2]+1),c(0,3),type="n",xlab="Samples",ylab="Expression value (Scaled)")
	abline(h=0,v=(altered@len),col=2)
	for(j in c(1:dim(exprmat)[1])){
		med <- exprmat[j,1]
		points((exprmat[j,]/med),type = "l",col = j)
	}
	}
)

setGeneric("altered2html",function(altered,filename,plotExprs=TRUE,plotScal=TRUE) standardGeneric("altered2html"))

setMethod("altered2html","altered",
	function(altered,filename,plotExprs=TRUE,plotScal=TRUE)
	{
	if(!is(altered,"altered"))
		stop("'altered' must be an object of class altered.")
		
	suffix<-tolower(substring(filename,nchar(filename)-4,nchar(filename)))
	if(suffix!=".html"){
		filename<-paste(filename,"html",sep=".")
		warning("Since the suffix of 'filename' is not 'html' '.html' is added",
			" to 'filename'.",call.=FALSE)
	}
	file.sep<-.Platform$file.sep
	tmp<-unlist(strsplit(filename,file.sep))
	path<-if(length(tmp)>1) paste(tmp[-length(tmp)],collapse=file.sep)
		else "."
	
	outfile<-file(filename,"w")
	html <- altered2body(altered,filename,plotExprs=plotExprs,plotScal=plotScal)
	cat(html,file=outfile)
	close(outfile)
	cat("Output is stored in ",filename,".\n",sep="")
		
	}
)

setGeneric("altered2body",function(altered,filename,tittle = "Altered Expression Analysis",plotExprs=TRUE,plotScal=TRUE) standardGeneric("altered2body"))

setMethod("altered2body","altered",
	function(altered,filename, tittle = "Altered Expression Analysis",plotExprs=TRUE,plotScal=TRUE)
	{
	type<-"text/css"

	genestable <- "<table><tr>"
	j <- 0
	for(i in rownames(altered@exprs)) {
		genestable <- paste(genestable,"<td style=\"padding-left: 10px;\">",i,"</td>",sep="\n")
		if((j+1)%%10 == 0) genestable <- paste(genestable,"</tr><tr>")
		j <- j+1
	}
	genestable <- paste(genestable,"</tr></table>")
	
	html <- paste("<html>","<head>","<title>Altered Expression Analysis</title>","</head>",
	"<body style=\"margin-left: 10px;\">","<h1 align=left>",tittle ,"</h1>",
	paste("<b>Genes:</b>",genestable),
	paste("<p><b>Output parameters:</b><br><spam style=\"margin-left: 10px;\"><b>- F-Score:</b>",altered@fscore,"</spam><br>"),
	paste("<spam style=\"margin-left: 10px;\"><b>- Residual relative variance:</b>",altered@rrv,"</spam><br>"),
	paste("<spam style=\"margin-left: 10px;\"><b>- Number of iterations:</b>",altered@iter,"</spam></p>"),
	paste("<p><b>Input parameters:</b><br><spam style=\"margin-left: 10px;\"><b>- vsize:</b>",altered@vsize,"</spam><br>"),
	paste("<spam style=\"margin-left: 10px;\"><b>- pctsubset:</b>",altered@pctsubset,"</spam><br>"),
	paste("<spam style=\"margin-left: 10px;\"><b>- Mean Filter:</b>",altered@filmed,"</spam></p>"),
	sep="\n")
	if(plotExprs)
		html <- paste(html,paste("<IMG src=\"",paste(filename,".png", sep=""),"\">",sep=""),sep="\n")
	if(plotScal)
		html <- paste(html,paste("<br><IMG src=\"",paste(filename,"Scal",".png", sep=""),"\">",sep=""),sep="\n")
	html <- paste(html,"</body>","</html>",sep="\n")
	
	if(plotExprs){
		png(paste(filename,".png", sep=""))
		plotExprs(altered)
		dev.off()
	}
	
	if(plotScal){
		png(paste(filename,"Scal",".png", sep=""))
		plotScal(altered)
		dev.off()
	}
	
	return(html)
	}
)
