require(methods)

setClass("alteredset",representation(set="list",num="numeric"),
prototype(set=list(),num=0))

setMethod("show","alteredset",
	function(object) print(object@set)
)

setGeneric("getAltered",function(alteredset,index) standardGeneric("getAltered"))

setMethod("getAltered","alteredset",
	function(alteredset,index){
		if(index <= alteredset@num) return(alteredset@set[[index]])
		else stop("The index is out of bound, the maximun index is ",alteredset@num)

	}
)

setGeneric("getFscore",function(alteredset) standardGeneric("getFscore"))

setMethod("getFscore","alteredset",
	function(alteredset){
		fscore <- c()
		for (i in 1:alteredset@num){
			fscore <- c(fscore,alteredset@set[[i]]@fscore)
		}
		fscore
	}
)

setGeneric("plotFscore",function(alteredset) standardGeneric("plotFscore"))

setMethod("plotFscore","alteredset",
	function(alteredset){
		fscore <- getFscore(alteredset)
		plot(log10(fscore), type = "b", col=4, pch=19, ylab = "log F-score", xlab = "Group")
	}
)

setGeneric("getAlteredGenes",function(alteredset,index) standardGeneric("getAlteredGenes"))

setMethod("getAlteredGenes","alteredset",
	function(alteredset,index){
		if(index <= alteredset@num) return(rownames(alteredset@set[[index]]@exprs))
		else stop("The index is out of bound, the maximun index is ",alteredset@num)

	}
)

setGeneric("orderAlteredSet",function(alteredset) standardGeneric("orderAlteredSet"))

setMethod("orderAlteredSet","alteredset",
	function(alteredset){
		fscores <- getFscore(alteredset)
		ord <- order(as.matrix(fscores))	
		result <- new("alteredset")
		for(i in ord){
			result@num <- result@num +1
			result@set[[result@num]] <- getAltered(alteredset,i)
		}
		return(result)
	}
)

setGeneric("alteredset2html",function(alteredset,filename,plotExprs=TRUE,plotScal=TRUE) standardGeneric("alteredset2html"))

setMethod("alteredset2html","alteredset",
	function(alteredset,filename,plotExprs=TRUE,plotScal=TRUE)
	{
	if(!is(alteredset,"alteredset"))
		stop("'altered' must be an object of class alteredset.")
		
	suffix<-tolower(substring(filename,nchar(filename)-4,nchar(filename)))
	if(suffix!=".html"){
		filename<-paste(filename,"html",sep=".")
		warning("Since the suffix of 'filename' is not 'html' '.html' is added",
			" to 'filename'.",call.=FALSE)
	}
	file.sep<-.Platform$file.sep
	tmp<-unlist(strsplit(filename,file.sep))
	path<-if(length(tmp)>1) paste(tmp[-length(tmp)],collapse=file.sep)
		else "."
	
	outfile<-file(filename,"w")
	
	for (i in 1:alteredset@num){
		html <- altered2body(alteredset@set[[i]],paste(filename,i), tittle=paste("Result for Group ",i),plotExprs=plotExprs,plotScal=plotScal)
		cat(html,file=outfile)
	}
	
	close(outfile)
	cat("Output is stored in ",filename,".\n",sep="")
		
	}
)


