\name{altered}
\docType{class}
\alias{altered}
\alias{getExprs}
\alias{getGenes}
\alias{plotExprs}
\alias{plotScal}
\alias{altered2html}
\alias{altered2body}

\title{Class altered}
\description{This is a class representation for alteredExpressionGroup procedure.}
\section{Objects from the Class}{
   Objects can be created using the function \code{alteredExpressionGroup}. }
}
\section{Slots}{
  \describe{
    \item{\code{exprs}:}{Object of class \code{"data.frame"} containing 
       the expression values of the resulting group of genes.}
    \item{\code{fscore}:}{Object of class \code{"numeric"} representing
       the expected F-score (statistical parameter) of this group of genes}
    \item{\code{rrv}:}{Object of class \code{"numeric"} containing
       the Residual Relative Variance (RRV) of this group of genes.}
    \item{\code{len}:}{Object of class \code{"numeric"} containing
       he number of control samples. The control samples have to be 
       placed as the initial columns in the expresion matrix.}
    \item{\code{iter}:}{Object of class \code{"numeric"} representing
       the number of iterations done by the algorithm to find the group. }
    \item{\code{vsize}:}{Object of class \code{"numeric"} representing
       the value used to modulate or variate the effect of the group size.}
    \item{\code{pctsubset}:}{Object of class \code{"numeric"} containing
       the percentage of in-out genes that is changed in each iteration.}
     \item{\code{filmed}:}{Object of class \code{"numeric"} containing
       the value of the prefilter used, that corresponds to a certain 
       difference in the mean expression value of the control samples 
       versus the mean expression value of the altered samples.}
  }
}
\section{Methods}{
  \describe{
    \item{getExprs}{\code{signature(altered = "altered")}: Get the expression values of the group.}
    \item{getGenes}{\code{signature(altered = "altered")}: Get the gene identifiers of the group.}
    \item{plotExprs}{\code{altered(altered = "altered")}: Generates a group expression plot.}
    \item{plotScal}{\code{signature(altered = "altered")}: Generates a group expression scaled-plot, 
    scaling all the values by making 1 the gene expression values of the first sample.}
    \item{altered2html}{\code{signature(altered = "altered", filename = "character", plotExprs = "logical", 
        plotScal = "logical")}: Generates a HTML file representing the group.\cr 
	filename - is the name of the file.\cr
	plotExprs - includes the group expression plot in the html file.\cr
	plotScal - includes the group expression scaled-plot in the html file.}
    \item{show}{\code{signature(altered = "altered")}: Shows the output of the alteredExpressionGroup 
    analysis.}
  }
}

\references{
   Prieto C, Rivas MJ, Sanchez JM, Lopez-fidalgo J and De Las Rivas J (2006) 
   Algorithm to find gene expression profiles of differential deregulation and identify families of disease-altered genes. 
   Bioinformatics (PMID: 16500942)
}
\author{Prieto C, Rivas MJ, Sanchez JM, Lopez-fidalgo J and De Las Rivas J 
   email:\email{jrivas@usal.es} or \email{cprieto@usal.es}}

\seealso{
  \code{\link{alteredExpressionGroup}},\code{\link{alteredExpressionGroupSet}},\code{\link{alteredSet}}
  }
}
\examples{\dontrun{
 # Generates the data for the example
 data <- as.data.frame(rbind(cbind(matrix(rep(5:9,120) + rnorm(600,mean=0,sd=0.2),ncol=6,byrow=TRUE),matrix(sample(1:15,1000,replace=TRUE),ncol=10)),matrix(sample(1:15,3200,replace=TRUE),ncol=16)))
 # Run the algorithm. This function searchs just for one group
 altered <- alteredExpressionGroup(data,6)
 # Get the class of the object
 class(altered)
 # Get the expression values of the group
 getExprs(altered)
 # Get the gene identifiers of the group
 getGenes(altered)
 # Generates a group expression plot
 plotExprs(altered)
 # Geterates a group expression scaled-plot
 plotScal(altered)
}}
\keyword{classes}
