\name{alteredExpression-package}
\alias{alteredExpression-package}
\alias{alteredExpression}
\alias{alteredexpression}
\docType{package}
\title{
Altered Expression
}
\description{
Package that searches for the genes which present the most significant alteration in their expression profiles, by comparing disease samples (i.e. the altered state) with control or healthy samples (i.e. the control state). The algorithm provides groups of genes and assigns a statistical measure of significance to each group. Adequate performance of the method is achieved when the algorithm that finds deregulation is applied to differentially expressed genes previously selected
}
\details{
\tabular{ll}{
Package: \tab alteredExpression\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2006-03-29\cr
License: \tab GPL version 2 or newer\cr
}
}
\author{
   Prieto C, Rivas MJ, Sanchez JM, Lopez-fidalgo J and De Las Rivas J 
  email:\email{jrivas@usal.es} or \email{cprieto@usal.es}
}
\references{
   Prieto C, Rivas MJ, Sanchez JM, Lopez-fidalgo J and De Las Rivas J (2006) 
   Algorithm to find gene expression profiles of differential deregulation and identify families of disease-altered genes. 
   Bioinformatics (PMID: 16500942)
}
\seealso{
   \code{\link{alteredExpressionGroup}},\code{\link{alteredExpressionGroupSet}},\code{\link{alteredSet}},\code{\link{altered}}
}
}
\examples{\dontrun{
 # Generates the data for the example
 data <- as.data.frame(rbind(cbind(matrix(rep(5:9,120) + rnorm(600,mean=0,sd=0.2),ncol=6,byrow=TRUE),matrix(sample(1:15,1000,replace=TRUE),ncol=10)),matrix(sample(1:15,3200,replace=TRUE),ncol=16)))
 # Run the algorithm. This function searchs for three groups
 alteredset <- alteredExpressionGroupSet(data,6,numGroups=3)
 # Get the class of the object
 class(alteredset)
 # Get the gene identifiers of the first group.
 getAlteredGenes(alteredset,1)
 # Get a vector with the F-score values of all the groups generated.
 getFscore(alteredset)
 # Generates a plot representing the F-score values of all the groups generated.
 plotFscore(alteredset)
 # Generates an alteredset ordered by F-score.
 alteredset.order <- orderAlteredSet(alteredset)
 # Generates a plot representing the F-score values of all the groups ordered by F-score.
 plotFscore(alteredset.order)
 # Get the group generated in the first position.
 altered <- getAltered(alteredset,1)
 # Get the class of the object
 class(altered)
 # Get the expression values of the group
 getExprs(altered)
 # Get the gene identifiers of the group
 getGenes(altered)
 # Generates a group expression plot
 plotExprs(altered)
 # Geterates a group expression scaled-plot
 plotScal(altered)
}}
\keyword{data}
