\name{alteredExpressionGroupSet}
\alias{alteredExpressionGroupSet}
\concept{microarray}
\concept{gene expression}
\title{alteredExpressionGroupSet}
\description{Algorithm to find in a genome-wide expression dataset 
	(usually obtained with microarrays) the set of groups of genes which presents the most 
	variable or altered figures in their expression profiles when comparing a control 
	set (i.e. control samples) versus a query set (i.e. disease or altered samples). 
	It searchs for consecutive groups with decreasing variability.
}
\usage{
alteredExpressionGroupSet(A.data.frame, length.1, maxiter=500, initialSize = 20, vSize = 0.5, pctSubset = 0.1, filMed = 0, numGroups = 7, maxnull = 20)
}
\arguments{
  \item{A.data.frame}{Two-dimensional data frame with samples (subjects, arrays) as columns and genes (genes, gene probes) as rows.}
  \item{length.1}{Number of columns in the data frame that correspond to control samples (placing the controls always at the beginning, starting with column 1).}
  \item{maxiter}{Maximum number of iterations allowed to find one group. A value of 500 iterations is set up by default.}
  \item{initialSize}{Number of genes included in the group for the initial random sampling of the dataset. A value of 20 genes is set up by default.}
  \item{vSize}{Parameter to modulate or variate the effect of the group size. It can vary between 0 and 1, being close to 0 for higher size effect and close to 1 for lower size effect. The vSize is fixed to 0.5 by default.}
  \item{pctSubset}{Parameter, varying between 0 and 1, that fix the percentage of in-out genes (ioGenes) that are randomly selected and changed every time the algorithm iterates. A value of 0.1 (10pct) is set up by default.}
  \item{filMed}{Means prefilter between control and altered samples. This parameter excludes from the analysis the input genes that do not present a minimal change in mean expression.}
  \item{numGroups}{Maximum number of groups generated by the algorithm. It is fixed to 7 by default.}
  \item{maxnull}{Maximum number of times that the algorithm allows that the resulting group is null before stopping. It is fixed to 20 by default.}
}
\details{See references for further details.
}
\value{
  \item{alteredSet}{An object of class alteredSet.}
}
\author{Prieto C,  Rivas MJ, Sanchez JM, Lopez-fidalgo J and De Las Rivas J
email:\email{jrivas@usal.es},\url{http://bioinfow.dep.usal.es}
}
\references{
  Prieto C,  Rivas MJ, Sanchez JM, Lopez-fidalgo J and De Las Rivas J (2005) 
  Algorithm to find gene expression profiles of differential deregulation and 
  identify families of disease-altered genes. Bioinformatics (PMID: 16500942)
  \url{http://bioinfow.dep.usal.es/AlteredExpression}.
}
\seealso{\code{\link{alteredExpressionGroup}},\code{\link{altered}},\code{\link{alteredset}}}
\examples{
 # Generates the data for the example
 data <- as.data.frame(rbind(cbind(matrix(rep(5:9,120) + rnorm(600,mean=0,sd=0.2),ncol=6,byrow=TRUE),matrix(sample(1:15,1000,replace=TRUE),ncol=10)),matrix(sample(1:15,3200,replace=TRUE),ncol=16)))
 # Run the algorithm. This function searchs for three groups
 alteredset <- alteredExpressionGroupSet(data,6,numGroups=3)
 # Get the class of the object
 class(alteredset)
 # Get the gene identifiers of the first group.
 getAlteredGenes(alteredset,1)
 # Get a vector with the F-score values of all the groups generated.
 getFscore(alteredset)
 # Generates a plot representing the F-score values of all the groups generated.
 plotFscore(alteredset)
 # Generates an alteredset ordered by F-score.
 alteredset.order <- orderAlteredSet(alteredset)
 # Generates a plot representing the F-score values of all the groups ordered by F-score.
 plotFscore(alteredset.order)
 # Get the group generated in the first position.
 altered <- getAltered(alteredset,1)
 # Get the class of the object
 class(altered)
 # Get the expression values of the group
 getExprs(altered)
 # Get the gene identifiers of the group
 getGenes(altered)
 # Generates a group expression plot
 plotExprs(altered)
 # Geterates a group expression scaled-plot
 plotScal(altered)

}
\keyword{datagen}
