\name{alteredset}
\docType{class}
\alias{alteredset}
\alias{alteredSet}
\alias{getAltered}
\alias{getAlteredGenes}
\alias{getFscore}
\alias{plotFscore}
\alias{alteredset2html}
\alias{orderAlteredSet}

\title{Class alteredset}
\description{This is a class representation for alteredExpressionGroup procedure.}
\section{Objects from the Class}{
   Objects can be created using the function \code{alteredExpressionGroup}. }
}
\section{Slots}{
  \describe{
    \item{\code{set}:}{Object of class \code{"list"} containing 
       the groups of genes as objects generated by alteredExpresionGroupSet procedure.}
    \item{\code{num}:}{Object of class \code{"numeric"} containing
       the number of groups generated by alteredExpressionGroupSet procedure.}
  }
}
\section{Methods}{
  \describe{
    \item{getAltered}{\code{signature(alteredset = "alteredset", index = "numeric")}: Get the group generated in the index position.}
    \item{getAlteredGenes}{\code{signature(alteredset = "alteredset", index = "numeric")}: Get the list of genes generated in the index position.}
    \item{getFscore}{\code{altered(alteredset = "alteredset")}:  Get a vector with the F-score values of all the groups generated.}
    \item{plotFscore}{\code{signature(alteredset = "alteredset")}: Generates a plot representing the F-score values of all the groups generated.}
    \item{orderAlteredSet}{\code{signature(alteredset = "alteredset")}: Generates an alteredset ordered by F-score.}
    \item{alteredset2html}{\code{signature(alteredset = "alteredset", filename = "character", plotExprs = "logical", 
    plotScal = "logical")}: Generate a HTML file representing the set of groups obtained.\cr
	filename - is the name of the file. \cr
        plotExprs - includes for each group the expression plot in the html file. \cr
        plotScal - includes for each group the scaled-plot in the html file.}
    \item{show}{\code{signature(altered = "altered")}: Shows the output of the alteredExpressionGroupSet analysis.}
  }
}

\references{
   Prieto C, Rivas MJ, Sanchez JM, Lopez-fidalgo J and De Las Rivas J (2006) 
   Algorithm to find gene expression profiles of differential deregulation and identify families of disease-altered genes. 
   Bioinformatics (PMID: 16500942)
}
\author{Prieto C, Rivas MJ, Sanchez JM, Lopez-fidalgo J and De Las Rivas J 
   email:\email{jrivas@usal.es} or \email{cprieto@usal.es}}

\seealso{
  \code{\link{alteredExpressionGroup}},\code{\link{alteredExpressionGroupSet}},\code{\link{altered}},
  }
}
\examples{\dontrun{
 # Generates the data for the example
 data <- as.data.frame(rbind(cbind(matrix(rep(5:9,120) + rnorm(600,mean=0,sd=0.2),ncol=6,byrow=TRUE),matrix(sample(1:15,1000,replace=TRUE),ncol=10)),matrix(sample(1:15,3200,replace=TRUE),ncol=16)))
 # Run the algorithm. This function searchs for three groups
 alteredset <- alteredExpressionGroupSet(data,6,numGroups=3)
 # Get the class of the object
 class(alteredset)
 # Get the gene identifiers of the first group.
 getAlteredGenes(alteredset,1)
 # Get a vector with the F-score values of all the groups generated.
 getFscore(alteredset)
 # Generates a plot representing the F-score values of all the groups generated.
 plotFscore(alteredset)
 # Generates an alteredset ordered by F-score.
 alteredset.order <- orderAlteredSet(alteredset)
 # Generates a plot representing the F-score values of all the groups ordered by F-score.
 plotFscore(alteredset.order)
 # Get the group generated in the first position.
 altered <- getAltered(alteredset,1)
 # Get the class of the object
 class(altered)
 # Get the expression values of the group
 getExprs(altered)
 # Get the gene identifiers of the group
 getGenes(altered)
 # Generates a group expression plot
 plotExprs(altered)
 # Geterates a group expression scaled-plot
 plotScal(altered)
}}
\keyword{classes}
